pyjabber.features.presence package
==================================

Submodules
----------

pyjabber.features.presence.PresenceFeature module
-------------------------------------------------

.. automodule:: pyjabber.features.presence.PresenceFeature
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.features.presence
   :members:
   :undoc-members:
   :show-inheritance:
